@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "edna-theme" "0.2.6"
+(define-package "edna-theme" "20260203.1528"
   "A dark, Edna-inspired theme."
   '((emacs "26.1"))
   :url "https://codeberg.org/golanv/edna-theme"
-  :commit "78da1fcde3d03f4ff65b310d19319dc26140566b"
-  :revdesc "78da1fcde3d0"
+  :commit "39164ec3c42fece3d1bd3eabb3d8210f01d9e58c"
+  :revdesc "39164ec3c42f"
   :keywords '("faces" "theme")
   :authors '(("golanv" . "https://codeberg.org/golanv"))
   :maintainers '(("golanv" . "https://codeberg.org/golanv")))
